==> haskell-microlens-aeson-2.2.0.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.2.0.1
id: microlens-aeson-2.2.0.1-Gk7h3BwhGW83gTBUuet9Eu
key: microlens-aeson-2.2.0.1-Gk7h3BwhGW83gTBUuet9Eu
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
           Copyright (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
stability: provisional
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
author: Colin Woodbury
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
abi: ec6e0486d34b306728073d8a00fe5e4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/microlens-aeson-2.2.0.1
hs-libraries: HSmicrolens-aeson-2.2.0.1-Gk7h3BwhGW83gTBUuet9Eu
depends:
    aeson-1.1.2.0-KSzOWeOw6cI7ymVovOXtxy
    attoparsec-0.13.1.0-2ptg9LSVcb1at70Z7RWD3 base-4.9.0.0
    bytestring-0.10.8.1 microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    scientific-0.3.4.12-JvEgWsdvKgxFZH5v4yXqI3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.2.0.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.2.0.1
id: microlens-aeson-2.2.0.1-L2ubz47yzGaCXmlBTKwmtx
key: microlens-aeson-2.2.0.1-L2ubz47yzGaCXmlBTKwmtx
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
           Copyright (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
stability: provisional
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
author: Colin Woodbury
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
abi: 32e556bb5168ae438afd09e1d8fd57ab
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-aeson-2.2.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/microlens-aeson-2.2.0.1
hs-libraries: HSmicrolens-aeson-2.2.0.1-L2ubz47yzGaCXmlBTKwmtx
depends:
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH
    attoparsec-0.13.1.0-oc29svN3SiFq1TojBIbwV base-4.9.0.0
    bytestring-0.10.8.1 microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    scientific-0.3.4.15-GEIRVwGBHHyElVCNt38fm3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
